@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.099_02';
+our $VERSION = '0.099_03';
 
 use Astro::Coord::ECI::Sun;
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
@@ -1688,7 +1688,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Wed Jul  4 13:41:56 2018 GMT
+# on Sat Jul  7 12:50:38 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1787,11 +1787,11 @@ __PACKAGE__->status( add => 27374, iridium => 'D', 'Iridium 94', 'Decayed 2018-0
 __PACKAGE__->status( add => 27375, iridium => '+', 'Iridium 95', '' );
 __PACKAGE__->status( add => 27376, iridium => '-', 'Iridium 96', 'Tumbling' );
 __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
-__PACKAGE__->status( add => 27451, iridium => '+', 'Iridium 98', '' );
+__PACKAGE__->status( add => 27451, iridium => 'S', 'Iridium 98', '' );
 
 # Summary:
-# Operational [+]: 19
-#       Spare [S]: 15
+# Operational [+]: 18
+#       Spare [S]: 16
 #    Tumbling [-]: 39
 #     Decayed [D]: 24
 
